Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(25)

Unified Diff: gclient_scm.py

Issue 1739021: Modify scm.GIT.GetUpstreamBranch to behave like git-cl. (Closed)
Patch Set: Created 10 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | scm.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gclient_scm.py
diff --git a/gclient_scm.py b/gclient_scm.py
index d69a1d3f49adc2ca1f8a197548737ecb0663faeb..5eddf23958d46dd728a8033e14aa09ac2aa9c9c0 100644
--- a/gclient_scm.py
+++ b/gclient_scm.py
@@ -237,11 +237,11 @@ class GitWrapper(SCMWrapper):
# 4) current branch based on a remote, switches to a new remote
# - exit
# GetUpstream returns something like 'refs/remotes/origin/master' for a
# tracking branch
# or 'master' if not a tracking branch (it's based on a specific rev/hash)
# or it returns None if it couldn't find an upstream
- upstream_branch = scm.GIT.GetUpstream(self.checkout_path)
+ upstream_branch = scm.GIT.GetUpstreamBranch(self.checkout_path)
if not upstream_branch or not upstream_branch.startswith('refs/remotes'):
current_type = "hash"
logging.debug("Current branch is based off a specific rev and is not "
@@ -237,11 +237,11 @@ class GitWrapper(SCMWrapper):
# 4) current branch based on a remote, switches to a new remote
# - exit
- # GetUpstream returns something like 'refs/remotes/origin/master' for a
- # tracking branch
+ # GetUpstreamBranch returns something like 'refs/remotes/origin/master' for
+ # a tracking branch
# or 'master' if not a tracking branch (it's based on a specific rev/hash)
# or it returns None if it couldn't find an upstream
« no previous file with comments | « no previous file | scm.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698